
/*****
      CC_MultiSensor.h -
      Header definitions for ZWave multilevel sensor support.

      c 2019-2020 Primordial Machine Vision Systems
*****/

#ifndef __CC_MULTISENSOR_H
#define __CC_MULTISENSOR_H

#include <ZW_classcmd.h>
#include <ZW_TransportEndpoint.h>


/**** Application Interface ****/

/* These are not implemented in the command class.  The application must
   do that. */

/* return the type or a default if the argument is invalid/unsupported
     type - sensor type requested in GET command
*/
extern uint8_t appSensorValidType(uint8_t type);

/* put the supported sensor type bit masks in the array
     masks - array of at least 11 bytes to hold the masks (modified)
     nmask - number of elements of mask that contain valid data (modified)
*/
extern void appSensorMask(uint8_t *masks, uint8_t *nmask);

/* return the bit mask for the corresponding sensor type
     type - sensor type requested in SUPPORT_GET_SCALE command
*/
extern uint8_t appSensorScaleMask(uint8_t type);

/* return the reading for the sensor type and scale
     type - sensor type requested in _GET command
     scale - unpacked _GET scale (ie. (byte >> 3) & 0x03 from the _GET byte)
*/
extern int32_t appSensorValue(uint8_t type, uint8_t scale);

/* return the precision/scale/size byte for _REPORT
     type - sensor type requested in _GET command
     scale - unpacked _GET scale (ie. (byte >> 3) & 0x03 from the _GET byte)
*/
extern uint8_t appSensorLevel(uint8_t type, uint8_t scale);



/**** Generic Interface ****/

/* command handler
     rxopt - receive packet options
     rxcmd - incoming command buffer
     rxlen - number of bytes in rxcmd
   returns RECEIVED_FRAME_STATUS_* flag
*/
extern received_frame_status_t
handleCCMultilevelSensor(RECEIVE_OPTIONS_TYPE_EX *rxopt,
                         ZW_APPLICATION_TX_BUFFER *rxcmd, uint8_t rxlen);

/* send sensor reading
     type - sensor value being reported
     value - sensor reading
     level - value's precision, scale, and size packed into a byte
*/
extern received_frame_status_t
sendSensorValue(uint8_t type, int32_t val, uint8_t level);



#endif   /* __CC_MULTISENSOR_H */

